Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(117)

Unified Diff: src/core/SkPtrRecorder.h

Issue 1316233002: Style Change: NULL->nullptr (Closed) Base URL: https://skia.googlesource.com/skia.git@master
Patch Set: 2015-08-27 (Thursday) 10:25:06 EDT Created 5 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/core/SkPixmap.cpp ('k') | src/core/SkPtrRecorder.cpp » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/core/SkPtrRecorder.h
diff --git a/src/core/SkPtrRecorder.h b/src/core/SkPtrRecorder.h
index 325471ea719999e9c7a57a9019f97cfaa68f095e..2d755e69e58d2818253ecf0b1d9734e6e14a8581 100644
--- a/src/core/SkPtrRecorder.h
+++ b/src/core/SkPtrRecorder.h
@@ -26,7 +26,7 @@ public:
/**
* Search for the specified ptr in the set. If it is found, return its
* 32bit ID [1..N], or if not found, return 0. Always returns 0 for NULL.
*/
uint32_t find(void*) const;
@@ -34,7 +34,7 @@ public:
* Add the specified ptr to the set, returning a unique 32bit ID for it
* [1...N]. Duplicate ptrs will return the same ID.
*
* If the ptr is NULL, it is not added, and 0 is returned.
*/
uint32_t add(void*);
@@ -71,7 +71,7 @@ public:
* Return the next ptr in the set or null if the end was reached.
*/
void* next() {
- return fIndex < fSet.fList.count() ? fSet.fList[fIndex++].fPtr : NULL;
+ return fIndex < fSet.fList.count() ? fSet.fList[fIndex++].fPtr : nullptr;
}
private:
@@ -85,7 +85,7 @@ protected:
private:
struct Pair {
- void* fPtr; // never NULL
+ void* fPtr; // never nullptr
uint32_t fIndex; // 1...N
};
« no previous file with comments | « src/core/SkPixmap.cpp ('k') | src/core/SkPtrRecorder.cpp » ('j') | no next file with comments »
@@ -26,7 +26,7 @@ public:
/**
* Search for the specified ptr in the set. If it is found, return its
- * 32bit ID [1..N], or if not found, return 0. Always returns 0 for NULL.
+ * 32bit ID [1..N], or if not found, return 0. Always returns 0 for nullptr.
*/
uint32_t find(void*) const;
@@ -34,7 +34,7 @@ public:
* [1...N]. Duplicate ptrs will return the same ID.
*
- * If the ptr is NULL, it is not added, and 0 is returned.
+ * If the ptr is nullptr, it is not added, and 0 is returned.
*/
uint32_t add(void*);

Powered by Google App Engine
This is Rietveld 408576698